source ../config.env

LICENSE_PUBLIC_KEYRING="./license/gpg/pubring.gpg"
LICENSE_PRIVATE_KEYRING="./license/gpg/secring.gpg"

if [ ! -f "$LICENSE_PUBLIC_KEYRING" ]; then
    echo "Public keyring not found. Please run ./generate_keys.sh first."
    exit 1
fi

if [ ! -f "$LICENSE_PRIVATE_KEYRING" ]; then
    echo "Private keyring not found. Please run ./generate_keys.sh first."
    exit 1
fi

# Ask the user for the licensed organization name
echo "Enter the name of the organization that will be licensed:"
read LICENSE_ORG_NAME

# Generate a random 8-character license reference (all caps)
LICENSE_REF=`cat /dev/urandom | tr -dc 'A-Z' | fold -w 8 | head -n 1`

# Use jq to replace the license reference and organization name in the template
jq --arg license_ref "$LICENSE_REF" --arg company "$LICENSE_ORG_NAME" '.reference_number = $license_ref | .company = $company' ./metadata.tpl.json > ./license/metadata.json.tmp

CUST_KEY_PUB=`gpg --homedir="./gpg_data" --armor --export "$IDENTITY_KEY_EMAIL"`
CUST_KEY_PRIV=`gpg --homedir="./gpg_data" --armor --export-secret-keys "$IDENTITY_KEY_EMAIL"`

jq --arg customer_private_key "$CUST_KEY_PRIV" --arg customer_public_key "$CUST_KEY_PUB" '.customer_private_key = $customer_private_key | .customer_public_key = $customer_public_key' ./license/metadata.json.tmp > ./license/metadata.json

cd ./license
rm ./metadata.json.tmp

tar -cf ./license.tar .
gpg --homedir="../gpg_data" --sign --default-key "$LICENSE_KEY_EMAIL" ./license.tar
rm ./license.tar
cd ../

# Rename the signed tar file to the license reference
mv ./license/license.tar.gpg ./"$LICENSE_REF".ghl

