source ../config.env

cat > ./.gen_script <<EOF
%echo Generating Customer key
%no-protection
Key-Type: 1
Key-Length: 4096
Subkey-Type: 1
Subkey-Length: 4096
Name-Real: $CUSTOMER_KEY_NAME
Name-Email: $CUSTOMER_KEY_EMAIL
Expire-Date: 0

%echo Generating License key
%no-protection
Key-Type: 1
Key-Length: 4096
Subkey-Type: 1
Subkey-Length: 4096
Name-Real: $LICENSE_KEY_NAME
Name-Email: $LICENSE_KEY_EMAIL
Expire-Date: 0

%echo Generating Master key
%no-protection
Key-Type: 1
Key-Length: 4096
Subkey-Type: 1
Subkey-Length: 4096
Name-Real: $MASTER_KEY_NAME
Name-Email: $MASTER_KEY_EMAIL
Expire-Date: 0

%no-protection
Key-Type: 1
Key-Length: 4096
Subkey-Type: 1
Subkey-Length: 4096
Name-Real: $PACKAGE_KEY_NAME
Name-Email: $PACKAGE_KEY_EMAIL
Expire-Date: 0

%echo Generating Identity key
Key-Type: 1
Key-Length: 1024
Subkey-Type: 1
Subkey-Length: 1024
Name-Real: $IDENTITY_KEY_NAME
Name-Email: $IDENTITY_KEY_EMAIL
Name-Comment: $IDENTITY_KEY_COMMENT
Expire-Date: 0
EOF

echo "Creating gpg_data directory"
rm -rf ./gpg_data # TODO: Remove this after debug.
mkdir -p ./gpg_data

echo "Generating signing keys"
gpg --homedir "./gpg_data" --batch --gen-key ./.gen_script
rm -f ./.gen_script

echo "Certifying keys"
echo "Certifying Customer key with Master"
gpg --yes --batch --homedir "./gpg_data/" --default-key "$MASTER_KEY_EMAIL" --sign-key "$CUSTOMER_KEY_EMAIL"

echo "Certifying License key with Master"
gpg --yes --batch --homedir "./gpg_data/" --default-key "$MASTER_KEY_EMAIL" --sign-key "$LICENSE_KEY_EMAIL"

echo "Certifying Package key with Master"
gpg --yes --batch --homedir "./gpg_data/" --default-key "$MASTER_KEY_EMAIL" --sign-key "$PACKAGE_KEY_EMAIL"

echo "Certifying Identity key with Customer"
gpg --yes --batch --homedir "./gpg_data" --default-key "$CUSTOMER_KEY_EMAIL" --sign-key "$IDENTITY_KEY_EMAIL"

echo "Generating keyrings for license file"
mkdir -p ./.gpg_tmp
mkdir -p ./.tmp

gpg --homedir "./gpg_data" --armor --export-secret-keys "$CUSTOMER_KEY_EMAIL" > ./.tmp/customer_secret_key.asc
gpg --homedir "./gpg_data" --armor --export-secret-keys "$IDENTITY_KEY_EMAIL" > ./.tmp/identity_secret_key.asc
gpg --homedir "./gpg_data" --armor --export "$IDENTITY_KEY_EMAIL" > ./.tmp/identity_public_key.asc

gpg --homedir "./.gpg_tmp" --import ./.tmp/customer_secret_key.asc
gpg --homedir "./.gpg_tmp" --import ./.tmp/identity_secret_key.asc

echo "Exporting keys"
mkdir -p ./license/gpg

cp ./.tmp/identity_public_key.asc ./license/gpg/pubring.gpg
gpg --homedir "./.gpg_tmp" --armor --export-secret-keys > ./license/gpg/secring.gpg

mkdir -p ./image_keys/enterprise
gpg --homedir "./gpg_data" --export "$CUSTOMER_KEY_EMAIL" > ./image_keys/enterprise/customer.gpg
gpg --homedir "./gpg_data" --export "$PACKAGE_KEY_EMAIL" > ./image_keys/enterprise/package.gpg
gpg --homedir "./gpg_data" --export "$LICENSE_KEY_EMAIL" > ./image_keys/enterprise/license.gpg

gpg --homedir "./gpg_data" --armor --export "$MASTER_KEY_EMAIL" > ./image_keys/master.asc

rm -r ./.gpg_tmp
rm -r ./.tmp
